@@ -1,24 +1,21 @@
 /* tslint:disable:no-unused-variable */
 
-import { TestBed, async } from "@angular/core/testing"
-import { AppComponent } from "./app.component"
+import { async, TestBed } from "@angular/core/testing";
+import { AppComponent } from "./app.component";
 
 describe("AppComponent", () => {
     beforeEach(() => {
         TestBed.configureTestingModule({
-            declarations: [
-                AppComponent
-            ],
-        })
-    })
-    
+            declarations: [AppComponent],
+        });
+    });
+
     it("should create the app", async(() => {
-        let fixture = TestBed.createComponent(AppComponent)
-        let app = fixture.debugElement.componentInstance
-        expect(app)
-            .toBeTruthy()
-    }))
-    
+        let fixture = TestBed.createComponent(AppComponent);
+        let app = fixture.debugElement.componentInstance;
+        expect(app).toBeTruthy();
+    }));
+
     // it(`should have as title 'app works!'`, async(() => {
     //   let fixture = TestBed.createComponent(AppComponent);
     //   let app = fixture.debugElement.componentInstance;
@@ -31,4 +28,4 @@ describe("AppComponent", () => {
     //   let compiled = fixture.debugElement.nativeElement;
     //   expect(compiled.querySelector('h1').textContent).toContain('app works!');
     // }));
-})
+});
